@@ -1,5 +1,6 @@
 from django.db import models
 from cms.models import CMSPlugin
+from django.template.defaultfilters import slugify
 
 class FAQList(models.Model):
     title = models.CharField(max_length=128)
@@ -7,6 +8,9 @@ class FAQList(models.Model):
     def __unicode__(self):
         return u"%s" % self.title
 
+    def get_slug(self):
+        return slugify(self.title)
+
 class FAQEntry(models.Model):
     faq_list = models.ForeignKey(FAQList, related_name="faq_entries")
     question = models.CharField(max_length=128)
